| Title: | C++ headers and static libraries of Protocol buffers |
|---|---|
| Description: | This package provides the headers and static library of Protocol buffers for other R packages to compile and link against. |
| Authors: | Mike Jiang |
| Maintainer: | Mike Jiang <[email protected]> |
| License: | BSD_3_clause |
| Version: | 2.25.0 |
| Built: | 2026-05-30 09:36:19 UTC |
| Source: | https://github.com/bioc/RProtoBufLib |
Output the LD flags for linking against pb. It is only needed to be called for windows. For nix-OS, the other package simply import this for the side effect of loading RProtoBuflib.
LdFlags()LdFlags()